@@ -39,6 +39,17 @@ Puppet::Type.newtype(:libvirtd_config) do
     defaultto false
   end
 
+  newparam(:quote, :boolean => true) do
+    desc 'Whether to quote the value. Defauls to `false`.'
+    newvalues(:true, :false)
+    defaultto false
+  end
+
+  newparam(:ensure_absent_val) do
+    desc 'A value that is specified as the value property will behave as if ensure => absent was specified'
+    defaultto('<SERVICE DEFAULT>')
+  end
+
   autorequire(:anchor) do
     ['nova::install::end']
   end
