@@ -47,10 +47,11 @@ describe 'nova::api' do
       it 'configures various stuff' do
         is_expected.to contain_nova_config('DEFAULT/instance_name_template').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('wsgi/api_paste_config').with_value('api-paste.ini')
-        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with_value('0.0.0.0')
-        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with_value('8774')
-        is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_value('0.0.0.0')
-        is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_value('8775')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('api/use_forwarded_for').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with_value('5')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with_value('5')
         is_expected.to contain_oslo__middleware('nova_config').with(
@@ -221,8 +222,9 @@ describe 'nova::api' do
     context 'when running nova API in wsgi for compute, and metadata in wsgi' do
       before do
         params.merge!({
-          :service_name => 'httpd',
-          :nova_metadata_wsgi_enabled => true })
+          :service_name               => 'httpd',
+          :nova_metadata_wsgi_enabled => true
+        })
       end
 
       let :pre_condition do
@@ -234,12 +236,15 @@ describe 'nova::api' do
       end
 
       it 'disable nova API service' do
-          is_expected.to contain_service('nova-api').with(
+        is_expected.to contain_service('nova-api').with(
           :ensure => 'stopped',
           :name   => platform_params[:nova_api_service],
           :enable => false,
           :tag    => 'nova-service',
         )
+        is_expected.to contain_nova_config('DEFAULT/metadata_workers').with_ensure('absent')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen').with_ensure('absent')
+        is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with_ensure('absent')
       end
 
     end
