@@ -2,12 +2,6 @@ require 'spec_helper'
 
 describe 'nova::compute::libvirt::qemu' do
 
-  let :pre_condition do
-   'include nova
-    include nova::compute
-    include nova::compute::libvirt'
-  end
-
   shared_examples_for 'nova compute libvirt with qemu' do
 
     context 'when not configuring qemu' do
@@ -28,7 +22,7 @@ describe 'nova::compute::libvirt::qemu' do
             "rm memory_backing_dir",
             "rm nbd_tls",
         ],
-      }).that_notifies('Service[libvirt]') }
+      }) }
     end
 
     context 'when configuring qemu by default' do
@@ -48,7 +42,7 @@ describe 'nova::compute::libvirt::qemu' do
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
-      }).that_notifies('Service[libvirt]') }
+      }) }
     end
 
     context 'when configuring qemu with overridden parameters' do
@@ -70,7 +64,7 @@ describe 'nova::compute::libvirt::qemu' do
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
-      }).that_notifies('Service[libvirt]') }
+      }) }
     end
 
     context 'when configuring qemu with group parameter' do
@@ -96,7 +90,7 @@ describe 'nova::compute::libvirt::qemu' do
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
-      }).that_notifies('Service[libvirt]') }
+      }) }
     end
 
     context 'when configuring qemu with vnc_tls' do
@@ -117,7 +111,7 @@ describe 'nova::compute::libvirt::qemu' do
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
-      }).that_notifies('Service[libvirt]') }
+      }) }
     end
 
     context 'when configuring qemu with default_tls_verify enabled' do
@@ -138,7 +132,7 @@ describe 'nova::compute::libvirt::qemu' do
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
-      }).that_notifies('Service[libvirt]') }
+      }) }
     end
 
     context 'when configuring qemu with vnc_tls_verify disabled' do
@@ -160,7 +154,7 @@ describe 'nova::compute::libvirt::qemu' do
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
-      }).that_notifies('Service[libvirt]') }
+      }) }
     end
 
     context 'when configuring qemu with default_tls_verify disabled' do
@@ -181,7 +175,7 @@ describe 'nova::compute::libvirt::qemu' do
             "set nbd_tls 0",
         ],
         :tag     => 'qemu-conf-augeas',
-      }).that_notifies('Service[libvirt]') }
+      }) }
     end
 
     context 'when configuring qemu with nbd_tls and libvirt >= 4.5' do
@@ -202,7 +196,7 @@ describe 'nova::compute::libvirt::qemu' do
             "set nbd_tls 1",
         ],
         :tag     => 'qemu-conf-augeas',
-      }).that_notifies('Service[libvirt]') }
+      }) }
     end
 
   end
