@@ -54,15 +54,17 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/snapshots_directory').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_ensure('absent')}
-      it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
-      it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
-      it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
+      it { is_expected.to contain_nova_config('libvirt/inject_password').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/inject_key').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/sysinfo_serial').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/device_detach_timeout').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/file_backed_memory').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/images_type').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('<SERVICE DEFAULT>')}
@@ -74,10 +76,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value('<SERVICE DEFAULT>')}
-      it { is_expected.to contain_libvirtd_config('log_outputs').with_value('<SERVICE DEFAULT>').with_quote(true)}
-      it { is_expected.to contain_libvirtd_config('log_filters').with_value('<SERVICE DEFAULT>').with_quote(true)}
-      it { is_expected.to contain_libvirtd_config('tls_priority').with_value('<SERVICE DEFAULT>').with_quote(true)}
-      it { is_expected.to contain_libvirtd_config('ovs_timeout').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/wait_soft_reboot_seconds').with_value('<SERVICE DEFAULT>')}
     end
 
     describe 'with params' do
@@ -93,6 +92,7 @@ describe 'nova::compute::libvirt' do
           :disk_cachemodes                            => ['file=directsync','block=none'],
           :hw_disk_discard                            => 'unmap',
           :hw_machine_type                            => 'x86_64=machinetype1,armv7l=machinetype2',
+          :sysinfo_serial                             => 'auto',
           :enabled_perf_events                        => ['cmt', 'mbml', 'mbmt'],
           :device_detach_attempts                     => 8,
           :device_detach_timeout                      => 20,
@@ -103,6 +103,7 @@ describe 'nova::compute::libvirt' do
           :preallocate_images                         => 'space',
           :rx_queue_size                              => 512,
           :tx_queue_size                              => 1024,
+          :file_backed_memory                         => 2048,
           :images_type                                => 'raw',
           :volume_use_multipath                       => false,
           :nfs_mount_options                          => 'rw,intr,nolock',
@@ -119,6 +120,7 @@ describe 'nova::compute::libvirt' do
           :max_queues                                 => 4,
           :num_memory_encrypted_guests                => 255,
           :modular_libvirt                            => true,
+          :wait_soft_reboot_seconds                   => 120,
         }
       end
 
@@ -137,12 +139,14 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_value('file=directsync,block=none')}
       it { is_expected.to contain_nova_config('libvirt/hw_disk_discard').with_value('unmap')}
       it { is_expected.to contain_nova_config('libvirt/hw_machine_type').with_value('x86_64=machinetype1,armv7l=machinetype2')}
+      it { is_expected.to contain_nova_config('libvirt/sysinfo_serial').with_value('auto')}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('cmt,mbml,mbmt')}
       it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value(8)}
       it { is_expected.to contain_nova_config('libvirt/device_detach_timeout').with_value(20)}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value(512)}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value(1024)}
+      it { is_expected.to contain_nova_config('libvirt/file_backed_memory').with_value(2048)}
       it { is_expected.to contain_nova_config('libvirt/images_type').with_value('raw')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('rw,intr,nolock')}
@@ -154,21 +158,23 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/swtpm_group').with_value('libvirt')}
       it { is_expected.to contain_nova_config('libvirt/max_queues').with_value(4)}
       it { is_expected.to contain_nova_config('libvirt/num_memory_encrypted_guests').with_value(255)}
+      it { is_expected.to contain_nova_config('libvirt/wait_soft_reboot_seconds').with_value(120)}
+
       it {
         is_expected.to contain_service('libvirt').with(
-          :name     => 'custom_service',
-          :enable   => true,
-          :ensure   => 'running',
-          :before   => ['Service[nova-compute]']
+          :name   => 'custom_service',
+          :enable => true,
+          :ensure => 'running',
+          :before => ['Anchor[nova::service::end]', 'Service[nova-compute]']
         )
         is_expected.to contain_service('virtlockd').with(
-          :name     => 'virtlock',
-          :enable   => true,
+          :name   => 'virtlock',
+          :enable => true,
           :ensure => 'running'
         )
         is_expected.to contain_service('virtlogd').with(
-          :name     => 'virtlog',
-          :enable   => true,
+          :name   => 'virtlog',
+          :enable => true,
           :ensure => 'running'
         )
 
@@ -263,20 +269,20 @@ describe 'nova::compute::libvirt' do
         :name   => 'libvirtd',
         :enable => true,
         :ensure => 'running',
-        :before => ['Service[nova-compute]'],
+        :before => ['Anchor[nova::service::end]', 'Service[nova-compute]'],
       )}
       it { is_expected.to contain_service('messagebus').with(
         :ensure => 'running',
         :enable => true,
-        :before => ['Service[libvirt]'],
+        :before => ['Anchor[nova::service::end]', 'Service[libvirt]'],
         :name   => 'dbus'
       ) }
 
       it { is_expected.to contain_nova_config('DEFAULT/compute_driver').with_value('libvirt.LibvirtDriver')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('kvm')}
-      it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
-      it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
-      it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
+      it { is_expected.to contain_nova_config('libvirt/inject_password').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/inject_key').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/device_detach_attempts').with_value('<SERVICE DEFAULT>')}
