@@ -35,7 +35,7 @@ describe 'nova::compute' do
       end
 
       it { is_expected.to contain_nova_config('DEFAULT/use_cow_images').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('DEFAULT/mkisofs_cmd').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('DEFAULT/mkisofs_cmd').with_value(platform_params[:mkisofs_cmd]) }
       it { is_expected.to contain_nova_config('DEFAULT/force_raw_images').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/virt_mkfs').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('DEFAULT/reserved_host_memory_mb').with_value('<SERVICE DEFAULT>') }
@@ -70,6 +70,7 @@ describe 'nova::compute' do
         :ensure => 'present',
       ) }
 
+      it { is_expected.to contain_class('nova::policy') }
       it { is_expected.to contain_class('nova::availability_zone') }
 
       it 'installs mkisofs package and sets config_drive_format' do
@@ -80,11 +81,6 @@ describe 'nova::compute' do
         is_expected.to contain_package(platform_params[:mkisofs_package]).that_requires('Anchor[nova::install::begin]')
         is_expected.to contain_package(platform_params[:mkisofs_package]).that_comes_before('Anchor[nova::install::end]')
       end
-
-      it 'configures nova pci_passthrough_whitelist' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
-      end
     end
 
     context 'with overridden parameters' do
@@ -107,10 +103,6 @@ describe 'nova::compute' do
           :resize_confirm_window              => '3',
           :shutdown_timeout                   => '100',
           :resume_guests_state_on_host_boot   => true,
-          :keymgr_backend                     => 'castellan.key_manager.barbican_key_manager.BarbicanKeyManager',
-          :barbican_endpoint                  => 'http://localhost',
-          :barbican_api_version               => 'v1',
-          :barbican_auth_endpoint             => 'http://127.0.0.1:5000/v3',
           :max_concurrent_builds              => 15,
           :max_concurrent_live_migrations     => '4',
           :sync_power_state_pool_size         => '10',
@@ -145,14 +137,6 @@ describe 'nova::compute' do
         })
       end
 
-      it 'configures barbican service' do
-        is_expected.to contain_nova_config('key_manager/backend').with_value('castellan.key_manager.barbican_key_manager.BarbicanKeyManager')
-        is_expected.to contain_nova_config('barbican/barbican_endpoint').with_value('http://localhost')
-        is_expected.to contain_nova_config('barbican/barbican_api_version').with_value('v1')
-        is_expected.to contain_nova_config('barbican/auth_endpoint').with_value('http://127.0.0.1:5000/v3')
-        is_expected.to contain_package('cryptsetup').with_ensure('installed')
-      end
-
       it 'configures vnc in nova.conf' do
         is_expected.to contain_nova_config('vnc/enabled').with_value(true)
         is_expected.to contain_nova_config('vnc/server_proxyclient_address').with_value('127.0.0.1')
@@ -226,56 +210,6 @@ describe 'nova::compute' do
       end
     end
 
-    context 'with pci params array' do
-      let :params do
-        {
-          :pci_passthrough => [
-            {
-              "vendor_id"  => "8086",
-              "product_id" => "0126"
-            },
-            {
-              "vendor_id"        => "9096",
-              "product_id"       => "1520",
-              "physical_network" => "physnet1"
-            }
-          ],
-        }
-      end
-
-      it 'configures nova pci_passthrough_whitelist entries' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
-          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
-        )
-      end
-    end
-
-    context 'with pci params JSON encoded string (deprecated)' do
-      let :params do
-        {
-          :pci_passthrough => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"physical_network\":\"physnet1\"}]",
-        }
-      end
-
-      it 'configures nova pci_passthrough_whitelist entries' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(
-          'value' => ['{"vendor_id":"8086","product_id":"0126"}','{"vendor_id":"9096","product_id":"1520","physical_network":"physnet1"}']
-        )
-      end
-    end
-
-    context 'when vcpu_pin_set and pci params are empty' do
-      let :params do
-        { :pci_passthrough => ""}
-      end
-      it 'clears pci_passthrough configuration' do
-        is_expected.to contain_class('nova::compute::pci')
-        is_expected.to contain_nova_config('pci/passthrough_whitelist').with(:value => '<SERVICE DEFAULT>')
-      end
-    end
-
     context 'with reserved_huge_pages array' do
       let :params do
         {
@@ -289,16 +223,7 @@ describe 'nova::compute' do
       end
     end
 
-    context 'should raise an error, when cpu_dedicated_set and vcpu_pin_set both are defined' do
-      let :params do
-        { :vcpu_pin_set      => ['4-12','^8','15'],
-          :cpu_dedicated_set => ['4-12','^8','15'], }
-      end
-
-      it { should raise_error(Puppet::Error, /vcpu_pin_set is deprecated. vcpu_pin_set and cpu_dedicated_set are mutually exclusive./) }
-    end
-
-    context 'when cpu_shared_set and cpu_dedicated_set both are set, but not vcpu_pin_set' do
+    context 'when cpu_shared_set and cpu_dedicated_set both are set' do
       let :params do
         { :cpu_shared_set    => ['4-12','^8','15'],
           :cpu_dedicated_set => ['2-10','^5','14'], }
@@ -306,7 +231,6 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_nova_config('compute/cpu_shared_set').with_value('4-12,^8,15') }
       it { is_expected.to contain_nova_config('compute/cpu_dedicated_set').with_value('2-10,^5,14') }
-      it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with_ensure('absent') }
     end
 
     context 'when cpu_dedicated_set is defined but cpu_shared_set is not' do
@@ -316,38 +240,15 @@ describe 'nova::compute' do
 
       it { is_expected.to contain_nova_config('compute/cpu_dedicated_set').with_value('4-12,^8,15') }
       it { is_expected.to contain_nova_config('compute/cpu_shared_set').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with_ensure('absent') }
     end
 
-    context 'when cpu_shared_set is defined, but cpu_dedicated_set and vcpu_pin_set are not' do
+    context 'when cpu_shared_set is defined, but cpu_dedicated_set is not' do
       let :params do
         { :cpu_shared_set => ['4-12', '^8', '15'] }
       end
 
       it { is_expected.to contain_nova_config('compute/cpu_shared_set').with_value('4-12,^8,15') }
       it { is_expected.to contain_nova_config('compute/cpu_dedicated_set').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with_ensure('absent') }
-    end
-
-    context 'when cpu_shared_set and vcpu_pin_set are defined, but cpu_dedicated_set is not' do
-      let :params do
-        { :cpu_shared_set => ['4-12','^8','15'],
-          :vcpu_pin_set   => ['2-10','^5','14'], }
-      end
-
-      it { is_expected.to contain_nova_config('compute/cpu_shared_set').with_value('4-12,^8,15') }
-      it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with_value('2-10,^5,14') }
-      it { is_expected.to contain_nova_config('compute/cpu_dedicated_set').with_value('<SERVICE DEFAULT>') }
-    end
-
-    context 'when vcpu_pin_set is set, but cpu_shared_set and cpu_dedicated_set are not' do
-      let :params do
-         { :vcpu_pin_set => ['4-12','^8','15'] }
-      end
-
-      it { is_expected.to contain_nova_config('DEFAULT/vcpu_pin_set').with_value('4-12,^8,15') }
-      it { is_expected.to contain_nova_config('compute/cpu_shared_set').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('compute/cpu_dedicated_set').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'when neutron_physnets_numa_nodes_mapping and neutron_tunnel_numa_nodes are empty' do
@@ -408,12 +309,12 @@ describe 'nova::compute' do
 
     context 'while not managing service state' do
       let :params do
-        { :enabled           => false,
+        {
           :manage_service    => false,
         }
       end
 
-      it { is_expected.to contain_service('nova-compute').without_ensure }
+      it { is_expected.to_not contain_service('nova-compute') }
     end
 
     context 'with instance_usage_audit parameter set to false' do
@@ -457,24 +358,33 @@ describe 'nova::compute' do
       case facts[:osfamily]
       when 'Debian'
         let (:platform_params) do
-          { :nova_compute_package => 'nova-compute',
+          {
+            :nova_compute_package => 'nova-compute',
             :nova_compute_service => 'nova-compute',
-            :mkisofs_package => 'genisoimage' }
+            :mkisofs_package      => 'genisoimage',
+            :mkisofs_cmd          => '<SERVICE DEFAULT>'
+          }
         end
       when 'RedHat'
         let (:platform_params) do
-          { :nova_compute_package => 'openstack-nova-compute',
-            :nova_compute_service => 'openstack-nova-compute' }
+          {
+            :nova_compute_package => 'openstack-nova-compute',
+            :nova_compute_service => 'openstack-nova-compute'
+          }
         end
-        if facts[:operatingsystemmajrelease] > '8'
+        if facts[:operatingsystemmajrelease].to_i >= 9
           before do
             platform_params.merge!({
-              :mkisofs_package => 'xorriso' })
+              :mkisofs_package => 'xorriso',
+              :mkisofs_cmd     => 'mkisofs'
+            })
           end
         else
           before do
             platform_params.merge!({
-              :mkisofs_package => 'genisoimage' })
+              :mkisofs_package => 'genisoimage',
+              :mkisofs_cmd     => '<SERVICE DEFAULT>'
+            })
           end
         end
       end
