@@ -24,11 +24,11 @@ describe 'nova::conductor' do
 
     context 'with manage_service as false' do
       let :params do
-        { :enabled        => true,
+        {
           :manage_service => false
         }
       end
-      it { is_expected.to contain_service('nova-conductor').without_ensure }
+      it { is_expected.to_not contain_service('nova-conductor') }
     end
 
     context 'with package version' do
@@ -60,33 +60,6 @@ describe 'nova::conductor' do
       it { is_expected.to contain_nova_config('DEFAULT/enable_new_services').with_value(false) }
     end
 
-    context 'with default database parameters' do
-      let :pre_condition do
-        "include nova::db"
-      end
-
-      it { is_expected.to_not contain_nova_config('database/connection') }
-      it { is_expected.to_not contain_nova_config('database/slave_connection') }
-      it { is_expected.to_not contain_nova_config('database/connection_recycle_time').with_value('<SERVICE DEFAULT>') }
-    end
-
-    context 'with overridden database parameters' do
-      let :pre_condition do
-        "class { 'nova::db':
-           database_connection              => 'mysql://user:pass@db/db',
-           slave_connection                 => 'mysql://user:pass@slave/db',
-           database_connection_recycle_time => '30',
-         }
-        "
-      end
-
-      it { is_expected.to contain_oslo__db('nova_config').with(
-        :connection              => 'mysql://user:pass@db/db',
-        :slave_connection        => 'mysql://user:pass@slave/db',
-        :connection_recycle_time => '30',
-      )}
-    end
-
   end
 
   on_supported_os({
