@@ -20,6 +20,7 @@ describe 'nova::keystone::service_user' do
           :project_name            => 'services',
           :user_domain_name        => 'Default',
           :project_domain_name     => 'Default',
+          :system_scope            => '<SERVICE DEFAULT>',
           :insecure                => '<SERVICE DEFAULT>',
           :send_service_user_token => false,
           :auth_type               => 'password',
@@ -41,6 +42,7 @@ describe 'nova::keystone::service_user' do
           :project_name            => 'service_project',
           :user_domain_name        => 'domainX',
           :project_domain_name     => 'domainX',
+          :system_scope            => 'all',
           :send_service_user_token => true,
           :insecure                => false,
           :auth_type               => 'password',
@@ -60,6 +62,7 @@ describe 'nova::keystone::service_user' do
           :project_name            => 'service_project',
           :user_domain_name        => 'domainX',
           :project_domain_name     => 'domainX',
+          :system_scope            => 'all',
           :send_service_user_token => true,
           :insecure                => false,
           :auth_type               => 'password',
