@@ -69,9 +69,6 @@ describe 'nova::logging' do
         :watch_log_file => '<SERVICE DEFAULT>',
         :debug          => '<SERVICE DEFAULT>',
       )
-      is_expected.to contain_file('/var/log/nova/nova-manage.log').with(
-        :owner        => 'nova',
-      )
     end
   end
 
@@ -88,9 +85,6 @@ describe 'nova::logging' do
         :watch_log_file      => true,
         :debug               => true,
       )
-      is_expected.to contain_file('/var/log/foo/nova-manage.log').with(
-        :owner        => 'nova',
-      )
     end
   end
 
@@ -113,9 +107,6 @@ describe 'nova::logging' do
        :instance_uuid_format           => '[instance: %(uuid)s] ',
        :log_date_format                => '%Y-%m-%d %H:%M:%S',
       )
-      is_expected.to contain_file('/var/log/foo/nova-manage.log').with(
-        :owner        => 'nova',
-      )
     end
   end
 
