@@ -17,6 +17,8 @@ describe 'nova::quota' do
       :key_pairs                   => '<SERVICE DEFAULT>',
       :server_groups               => '<SERVICE DEFAULT>',
       :server_group_members        => '<SERVICE DEFAULT>',
+      :recheck_quota               => '<SERVICE DEFAULT>',
+      :count_usage_from_placement  => '<SERVICE DEFAULT>',
     }
   end
 
@@ -50,6 +52,8 @@ describe 'nova::quota' do
           :key_pairs                   => 200,
           :server_groups               => 20,
           :server_group_members        => 20,
+          :recheck_quota               => true,
+          :count_usage_from_placement  => false,
         })
       end
 
