@@ -30,11 +30,11 @@ describe 'nova::serialproxy' do
 
     context 'with manage_service as false' do
       let :params do
-        { :enabled        => true,
+        {
           :manage_service => false
         }
       end
-      it { is_expected.to contain_service('nova-serialproxy').without_ensure }
+      it { is_expected.to_not contain_service('nova-serialproxy') }
     end
 
     context 'with package version' do
@@ -59,7 +59,7 @@ describe 'nova::serialproxy' do
       let (:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
+          if facts[:operatingsystem] == 'Debian'
             { :serialproxy_package_name => 'nova-consoleproxy',
               :serialproxy_service_name => 'nova-serialproxy' }
           else
