@@ -13,10 +13,12 @@ describe 'nova::vncproxy' do
     end
 
     context 'with default parameters' do
-
-      it { is_expected.to contain_nova_config('vnc/novncproxy_host').with(:value => '0.0.0.0') }
-      it { is_expected.to contain_nova_config('vnc/novncproxy_port').with(:value => '6080') }
-      it { is_expected.to contain_nova_config('vnc/auth_schemes').with(:value => 'none') }
+      it { is_expected.to contain_nova_config('vnc/novncproxy_host').with_value('0.0.0.0') }
+      it { is_expected.to contain_nova_config('vnc/novncproxy_port').with_value('6080') }
+      it { is_expected.to contain_nova_config('vnc/auth_schemes').with_value('none') }
+      it { is_expected.to contain_nova_config('vnc/vencrypt_client_key').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('vnc/vencrypt_client_cert').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('vnc/vencrypt_ca_certs').with_ensure('absent')}
 
       it { is_expected.to contain_package('nova-vncproxy').with(
         :name   => platform_params[:nova_vncproxy_package],
@@ -30,12 +32,12 @@ describe 'nova::vncproxy' do
 
       describe 'with manage_service as false' do
         let :params do
-          { :enabled        => true,
+          {
             :manage_service => false
           }
         end
 
-        it { is_expected.to contain_service('nova-vncproxy').without_ensure }
+        it { is_expected.to_not contain_service('nova-vncproxy') }
       end
 
       describe 'with package version' do
@@ -60,10 +62,10 @@ describe 'nova::vncproxy' do
           :vencrypt_ca    => '/baz.pem'
         }
       end
-      it { is_expected.to contain_nova_config('vnc/auth_schemes').with(:value => 'vencrypt,none') }
-      it { is_expected.to contain_nova_config('vnc/vencrypt_client_key').with(:value => '/foo.key')}
-      it { is_expected.to contain_nova_config('vnc/vencrypt_client_cert').with(:value => '/bar.pem')}
-      it { is_expected.to contain_nova_config('vnc/vencrypt_ca_certs').with(:value => '/baz.pem')}
+      it { is_expected.to contain_nova_config('vnc/auth_schemes').with_value('vencrypt,none') }
+      it { is_expected.to contain_nova_config('vnc/vencrypt_client_key').with_value('/foo.key')}
+      it { is_expected.to contain_nova_config('vnc/vencrypt_client_cert').with_value('/bar.pem')}
+      it { is_expected.to contain_nova_config('vnc/vencrypt_ca_certs').with_value('/baz.pem')}
     end
 
     context 'with vencrypt without noauth' do
@@ -76,10 +78,10 @@ describe 'nova::vncproxy' do
           :vencrypt_ca    => '/baz.pem'
         }
       end
-      it { is_expected.to contain_nova_config('vnc/auth_schemes').with(:value => 'vencrypt') }
-      it { is_expected.to contain_nova_config('vnc/vencrypt_client_key').with(:value => '/foo.key')}
-      it { is_expected.to contain_nova_config('vnc/vencrypt_client_cert').with(:value => '/bar.pem')}
-      it { is_expected.to contain_nova_config('vnc/vencrypt_ca_certs').with(:value => '/baz.pem')}
+      it { is_expected.to contain_nova_config('vnc/auth_schemes').with_value('vencrypt') }
+      it { is_expected.to contain_nova_config('vnc/vencrypt_client_key').with_value('/foo.key')}
+      it { is_expected.to contain_nova_config('vnc/vencrypt_client_cert').with_value('/bar.pem')}
+      it { is_expected.to contain_nova_config('vnc/vencrypt_ca_certs').with_value('/baz.pem')}
     end
 
     context 'with no auth method set' do
@@ -135,10 +137,6 @@ describe 'nova::vncproxy' do
       'include nova'
     end
 
-    before do
-      facts.merge!( :os_package_type => 'debian' )
-    end
-
     it { is_expected.to contain_file_line('/etc/default/nova-consoleproxy:NOVA_CONSOLE_PROXY_TYPE').with(
       :path    => '/etc/default/nova-consoleproxy',
       :match   => '^NOVA_CONSOLE_PROXY_TYPE=(.*)$',
@@ -160,7 +158,7 @@ describe 'nova::vncproxy' do
       let (:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
+          if facts[:operatingsystem] == 'Debian'
             { :nova_vncproxy_package => 'nova-consoleproxy',
               :nova_vncproxy_service => 'nova-novncproxy' }
           else
@@ -175,7 +173,7 @@ describe 'nova::vncproxy' do
 
       it_behaves_like 'nova_vnc_proxy'
 
-      if facts[:os_package_type] == 'debian'
+      if facts[:operatingsystem] == 'Debian'
         it_behaves_like 'nova_vnc_proxy debian package'
       end
 
