@@ -18,8 +18,9 @@ describe 'nova::wsgi::apache_api' do
         :bind_port                   => 8774,
         :group                       => 'nova',
         :path                        => '/',
+        :priority                    => 10,
         :servername                  => facts[:fqdn],
-        :ssl                         => true,
+        :ssl                         => false,
         :threads                     => 1,
         :user                        => 'nova',
         :workers                     => facts[:os_workers],
@@ -28,14 +29,20 @@ describe 'nova::wsgi::apache_api' do
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
         :wsgi_script_file            => 'nova-api',
         :wsgi_script_source          => platform_params[:api_wsgi_script_source],
+        :headers                     => nil,
+        :request_headers             => nil,
         :custom_wsgi_process_options => {},
-        :access_log_file             => false,
-        :access_log_format           => false,
+        :access_log_file             => nil,
+        :access_log_pipe             => nil,
+        :access_log_syslog           => nil,
+        :access_log_format           => nil,
         :error_log_file              => nil,
+        :error_log_pipe              => nil,
+        :error_log_syslog            => nil,
       )}
     end
 
-    context 'when overriding parameters using different ports' do
+    context 'when overriding parameters' do
       let :pre_condition do
         "include nova
          class { 'nova::keystone::authtoken':
@@ -51,16 +58,15 @@ describe 'nova::wsgi::apache_api' do
           :servername                  => 'dummy.host',
           :bind_host                   => '10.42.51.1',
           :api_port                    => 12345,
-          :ssl                         => false,
+          :ssl                         => true,
           :vhost_custom_fragment       => 'Timeout 99',
           :wsgi_process_display_name   => 'nova-api',
           :workers                     => 37,
           :custom_wsgi_process_options => {
             'python_path' => '/my/python/path',
           },
-          :access_log_file             => '/var/log/httpd/access_log',
-          :access_log_format           => 'some format',
-          :error_log_file              => '/var/log/httpd/error_log'
+          :headers                     => ['set X-XSS-Protection "1; mode=block"'],
+          :request_headers             => ['set Content-Type "application/json"'],
         }
       end
 
@@ -71,7 +77,7 @@ describe 'nova::wsgi::apache_api' do
         :group                       => 'nova',
         :path                        => '/',
         :servername                  => 'dummy.host',
-        :ssl                         => false,
+        :ssl                         => true,
         :threads                     => 1,
         :user                        => 'nova',
         :vhost_custom_fragment       => 'Timeout 99',
@@ -82,12 +88,11 @@ describe 'nova::wsgi::apache_api' do
         :wsgi_script_dir             => platform_params[:wsgi_script_path],
         :wsgi_script_file            => 'nova-api',
         :wsgi_script_source          => platform_params[:api_wsgi_script_source],
+        :headers                     => ['set X-XSS-Protection "1; mode=block"'],
+        :request_headers             => ['set Content-Type "application/json"'],
         :custom_wsgi_process_options => {
           'python_path' => '/my/python/path',
         },
-        :access_log_file             => '/var/log/httpd/access_log',
-        :access_log_format           => 'some format',
-        :error_log_file              => '/var/log/httpd/error_log'
       )}
     end
 
@@ -100,6 +105,119 @@ describe 'nova::wsgi::apache_api' do
       it { should raise_error(Puppet::Error, /nova::api class must be declared in composition layer./) }
     end
 
+    context 'with custom access logging' do
+      let :pre_condition do
+        "include nova
+         class { 'nova::keystone::authtoken':
+           password => 'secrete',
+         }
+         class { 'nova::api':
+           service_name   => 'httpd',
+         }"
+      end
+
+      let :params do
+        {
+          :access_log_format => 'foo',
+          :access_log_syslog => 'syslog:local0',
+          :error_log_syslog  => 'syslog:local1',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('nova_api_wsgi').with(
+        :access_log_format => params[:access_log_format],
+        :access_log_syslog => params[:access_log_syslog],
+        :error_log_syslog  => params[:error_log_syslog],
+      )}
+    end
+
+    context 'with access_log_file' do
+      let :pre_condition do
+        "include nova
+         class { 'nova::keystone::authtoken':
+           password => 'secrete',
+         }
+         class { 'nova::api':
+           service_name   => 'httpd',
+         }"
+      end
+
+      let :params do
+        {
+          :access_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('nova_api_wsgi').with(
+        :access_log_file => params[:access_log_file],
+      )}
+    end
+
+    context 'with access_log_pipe' do
+      let :pre_condition do
+        "include nova
+         class { 'nova::keystone::authtoken':
+           password => 'secrete',
+         }
+         class { 'nova::api':
+           service_name   => 'httpd',
+         }"
+      end
+
+      let :params do
+        {
+          :access_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('nova_api_wsgi').with(
+        :access_log_pipe => params[:access_log_pipe],
+      )}
+    end
+
+    context 'with error_log_file' do
+      let :pre_condition do
+        "include nova
+         class { 'nova::keystone::authtoken':
+           password => 'secrete',
+         }
+         class { 'nova::api':
+           service_name   => 'httpd',
+         }"
+      end
+
+      let :params do
+        {
+          :error_log_file => '/path/to/file',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('nova_api_wsgi').with(
+        :error_log_file => params[:error_log_file],
+      )}
+    end
+
+    context 'with error_log_pipe' do
+      let :pre_condition do
+        "include nova
+         class { 'nova::keystone::authtoken':
+           password => 'secrete',
+         }
+         class { 'nova::api':
+           service_name   => 'httpd',
+         }"
+      end
+
+      let :params do
+        {
+          :error_log_pipe => 'pipe',
+        }
+      end
+
+      it { should contain_openstacklib__wsgi__apache('nova_api_wsgi').with(
+        :error_log_pipe => params[:error_log_pipe],
+      )}
+    end
   end
 
   on_supported_os({
@@ -118,13 +236,11 @@ describe 'nova::wsgi::apache_api' do
         case facts[:osfamily]
         when 'Debian'
           {
-            :httpd_service_name     => 'apache2',
             :wsgi_script_path       => '/usr/lib/cgi-bin/nova',
             :api_wsgi_script_source => '/usr/bin/nova-api-wsgi',
           }
         when 'RedHat'
           {
-            :httpd_service_name     => 'httpd',
             :wsgi_script_path       => '/var/www/cgi-bin/nova',
             :api_wsgi_script_source => '/usr/bin/nova-api-wsgi',
           }
